@@ -4,11 +4,12 @@ use strict;
 use Carp;
 use Data::FormValidator;
 
-use Gantry::Utils::CRUDHelp qw( clean_dates clean_params form_profile );
+use Gantry::Utils::CRUDHelp qw( clean_dates 
+    clean_params form_profile write_file );
 
 use base 'Exporter';
 
-our @EXPORT_OK = qw( select_multiple_closure );
+our @EXPORT_OK = qw( select_multiple_closure write_file );
 
 #-----------------------------------------------------------
 # Constructor
@@ -239,7 +240,7 @@ sub edit {
     # Check form data
     my $results;
     if ( $self->validator ) {
-        $results = $self->validator(
+        $results = $self->validator->(
             {
                 your_self => $your_self,
                 params    => \%params,
