@@ -7,8 +7,39 @@ our @EXPORT = qw(
     clean_dates
     form_profile
     clean_params
+    write_file
 );
 
+sub write_file {
+    my( $self, $field, $archive ) = @_;
+    
+    my $upload = $self->file_upload( $field );
+
+    my $id = $upload->{unique_key};
+    $upload->{ident} = $id  . $upload->{suffix}; 
+    
+    my $file = File::Spec->catfile( $archive, $upload->{ident} );
+
+    open( FH, ">$file" ) or die "Error $!";
+    binmode FH;
+
+    my( $buffer, $buffer_size ) = ( '', 14096 );
+    while ( read( $upload->{filehandle}, $buffer, $buffer_size ) ) {
+        print FH $buffer;
+    }        
+    close FH;
+    
+    return( {
+        "$field"            => $file,
+        "${field}_ident"    => $upload->{ident},
+        "${field}_suffix"   => $upload->{suffix},
+        "${field}_mime"     => $upload->{mime},
+        "${field}_name"     => $upload->{name},
+        "${field}_size"     => $upload->{size},      
+     } );
+
+}
+
 # If a field is a date and its value is false, make it undef.
 sub clean_dates {
     my ( $params, $fields ) = @_;
@@ -134,6 +165,48 @@ check method of Data::FormValidator.
 
 =back
 
+=head2 write_file( <form field name>, <file archive> );
+
+write_file provides the code to collect a file from the form and write it to 
+disk. This is to be called in the edit_post_action or add_post_action callback.
+
+=head3 usage
+
+ sub edit_post_action {
+    my( $self, $row ) = @_;
+    
+    my %params = $self->get_param_hash;
+        
+    if ( defined %params{'myfile'} ) {
+    
+        my $u = $self->write_file( 'myfile', '/home/html/images' );
+        $row->update( $u );
+    }   
+ }
+ 
+
+=head3 recommend database fields
+
+ <file field>   varchar  -- /path to file>/11677952634.59186549016706.jpg
+ <file field>_ident  varchar -- 11677952634.59186549016706.jpg ( unique )
+ <file field>_suffix varchar -- .txt
+ <file field>_mime   varchar -- text/html
+ <file field>_name   varchar -- originalfilename.txt
+ <file field>_size   int     -- 2323
+
+=head3 returns
+
+will produce a hash ref
+ 
+ {
+    '<file field>'  => '/home/archive/11677952634.59186549016706.jpg',
+    '<file field>_ident'  => '11677952634.59186549016706.jpg',
+    '<file field>_suffix' => '.txt',
+    '<file field>_mime'   => 'text/html',
+    '<file field>_name'   => 'originalfilename.txt',
+    '<file field>_size'   => '2323',
+ }
+
 =head1 SEE ALSO
 
  Gantry::Plugins::AutoCRUD (for simpler situations)
